from typing import Optional

from pydantic import BaseModel, ConfigDict



class OrgDetails(BaseModel):
    """The user-modifiable parts of an organization."""

    allow_users_in_domain_to_auto_join: Optional[bool] = None

    billing_email: Optional[str] = None

    domain: Optional[str] = None

    image: Optional[str] = None

    name: Optional[str] = None

    phone: Optional[str] = None

    model_config = ConfigDict(protected_namespaces=())



from typing import Optional

from pydantic import BaseModel, ConfigDict



class JetstreamApiStats(BaseModel):
    """Jetstream API statistics."""

    errors: Optional[int] = None

    inflight: Optional[int] = None

    total: Optional[int] = None

    model_config = ConfigDict(protected_namespaces=())



from typing import List, Optional

from pydantic import BaseModel, ConfigDict

from ..models.kcl_code_completion_params import KclCodeCompletionParams


class KclCodeCompletionRequest(BaseModel):
    """A request to generate KCL code completions."""

    extra: Optional[KclCodeCompletionParams] = None

    max_tokens: Optional[int] = None

    n: Optional[int] = None

    nwo: Optional[str] = None

    prompt: Optional[str] = None

    stop: Optional[List[str]] = None

    stream: Optional[bool] = None

    suffix: Optional[str] = None

    temperature: Optional[float] = None

    top_p: Optional[float] = None

    model_config = ConfigDict(protected_namespaces=())



import datetime

from pydantic import BaseModel, ConfigDict



class Session(BaseModel):
    """An authentication session."""

    created_at: datetime.datetime

    expires_at: datetime.datetime

    token: str

    updated_at: datetime.datetime

    user_id: str

    model_config = ConfigDict(protected_namespaces=())



from typing import Optional

from pydantic import BaseModel, ConfigDict



class LeafNode(BaseModel):
    """Leaf node information."""

    auth_timeout: Optional[int] = None

    host: Optional[str] = None

    port: Optional[int] = None

    tls_timeout: Optional[int] = None

    model_config = ConfigDict(protected_namespaces=())




from pydantic import BaseModel, ConfigDict



class PerspectiveCameraParameters(BaseModel):
    """Defines a perspective view."""

    fov_y: float

    z_far: float

    z_near: float

    model_config = ConfigDict(protected_namespaces=())



from enum import Enum


class AiFeedback(str, Enum):
    """Human feedback on an AI response."""  # noqa: E501

    """# Thumbs up. """  # noqa: E501
    THUMBS_UP = "thumbs_up"
    """# Thumbs down. """  # noqa: E501
    THUMBS_DOWN = "thumbs_down"

    def __str__(self) -> str:
        return str(self.value)
